@@ -17,8 +17,11 @@ def with_pip(request):
 
 @pytest.fixture()
 def fake_create(monkeypatch):
-    def fake_create(self, location, *args):
-        location.mkdir(parents=True)
+    def fake_create(self, location, *args, prompt=None):
+        bin_dir = "Scripts" if sys.platform == "win32" else "bin"
+        suffix = ".exe" if sys.platform == "win32" else ""
+        (location / bin_dir).mkdir(parents=True)
+        (location / bin_dir / f"python{suffix}").touch()
 
     monkeypatch.setattr(backends.VirtualenvBackend, "perform_create", fake_create)
     monkeypatch.setattr(backends.VenvBackend, "perform_create", fake_create)
@@ -27,15 +30,13 @@ def fake_create(monkeypatch):
 
 @pytest.mark.usefixtures("fake_create")
 def test_venv_create(invoke, project):
-    project.project_config.pop("python.path", None)
+    project._saved_python = None
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     assert os.path.exists(venv_path)
-    assert "python.path" not in project.project_config
+    assert not project._saved_python
 
 
 @pytest.mark.usefixtures("fake_create")
@@ -49,14 +50,25 @@ def test_venv_create_in_project(invoke, project):
     assert "is not empty" in result.stderr
 
 
+@pytest.mark.usefixtures("fake_create")
+def test_venv_show_path(invoke, project):
+    project.project_config["venv.in_project"] = True
+    invoke(["venv", "create"], obj=project, strict=True)
+    invoke(["venv", "create", "--name", "test"], obj=project, strict=True)
+    result = invoke(["venv", "--path", "in-project"], obj=project, strict=True)
+    assert result.output.strip() == str(project.root / ".venv")
+    result = invoke(["venv", "--path", "test"], obj=project)
+    assert result.exit_code == 0
+    result = invoke(["venv", "--path", "foo"], obj=project)
+    assert result.exit_code == 1
+
+
 @pytest.mark.usefixtures("fake_create")
 def test_venv_list(invoke, project):
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
 
     result = invoke(["venv", "list"], obj=project)
     assert result.exit_code == 0, result.stderr
@@ -68,9 +80,7 @@ def test_venv_remove(invoke, project):
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     key = os.path.basename(venv_path)[len(get_venv_prefix(project)) :]
 
     result = invoke(["venv", "remove", "non-exist"], obj=project)
@@ -100,9 +110,7 @@ def test_venv_activate(invoke, mocker, project):
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     key = os.path.basename(venv_path)[len(get_venv_prefix(project)) :]
 
     mocker.patch("shellingham.detect_shell", return_value=("bash", None))
@@ -124,12 +132,12 @@ def test_venv_activate_custom_prompt(invoke, mocker, project):
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
     creator.assert_called_once_with(
-        None, [], False, False, project.project_config["venv.prompt"], False
+        None, [], False, False, prompt=project.project_config["venv.prompt"], with_pip=False
     )
 
 
 def test_venv_activate_project_without_python(invoke, project):
-    project.project_config.pop("python.path", None)
+    project._saved_python = None
     result = invoke(["venv", "activate"], obj=project)
     assert result.exit_code != 0
     assert "The project doesn't have a saved python.path" in result.stderr
@@ -144,9 +152,8 @@ def test_venv_activate_error(invoke, project):
     assert result.exit_code != 0
     assert "No virtualenv with key" in result.stderr
 
-    project.project_config["python.path"] = os.path.abspath("fake/bin/python")
+    project._saved_python = os.path.abspath("fake/bin/python")
     result = invoke(["venv", "activate"], obj=project)
-    print(project.project_config.get("python.path"))
     assert result.exit_code != 0, result.output + result.stderr
     assert "Can't activate a non-venv Python" in result.stderr
 
@@ -155,7 +162,7 @@ def test_venv_activate_error(invoke, project):
 @pytest.mark.parametrize("keep_pypackages", [True, False])
 def test_venv_auto_create(invoke, mocker, project, keep_pypackages):
     creator = mocker.patch("pdm.cli.commands.venv.backends.Backend.create")
-    del project.project_config["python.path"]
+    project._saved_python = None
     if keep_pypackages:
         project.root.joinpath("__pypackages__").mkdir(exist_ok=True)
     else:
@@ -176,9 +183,7 @@ def test_venv_purge(invoke, project):
 
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     result = invoke(["venv", "purge"], input="y", obj=project)
     assert result.exit_code == 0, result.stderr
     assert not os.path.exists(venv_path)
@@ -189,9 +194,7 @@ def test_venv_purge_force(invoke, project):
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     result = invoke(["venv", "purge", "-f"], obj=project)
     assert result.exit_code == 0, result.stderr
     assert not os.path.exists(venv_path)
@@ -206,9 +209,7 @@ def test_venv_purge_interactive(invoke, user_choices, is_path_exists, project):
     project.project_config["venv.in_project"] = False
     result = invoke(["venv", "create"], obj=project)
     assert result.exit_code == 0, result.stderr
-    venv_path = re.match(
-        r"Virtualenv (.+) is created successfully", result.output
-    ).group(1)
+    venv_path = re.match(r"Virtualenv (.+) is created successfully", result.output).group(1)
     result = invoke(["venv", "purge", "-i"], input=user_choices, obj=project)
     assert result.exit_code == 0, result.stderr
     assert os.path.exists(venv_path) == is_path_exists
