@@ -74,8 +74,9 @@ def test_convert_req_dict_to_req_line(req, result):
 @pytest.mark.parametrize(
     "line,expected",
     [
-        ("requests; os_name=>'nt'", "Invalid marker:"),
+        ("requests; os_name=>'nt'", None),
         ("./tests", r"The local path (.+)? is not installable"),
+        ("django>=2<4", None),
     ],
 )
 def test_illegal_requirement_line(line, expected):
@@ -83,11 +84,7 @@ def test_illegal_requirement_line(line, expected):
         parse_requirement(line)
 
 
-@pytest.mark.parametrize(
-    "line", ["requests >= 2.19.0", "https://github.com/pypa/pip/archive/1.3.1.zip"]
-)
+@pytest.mark.parametrize("line", ["requests >= 2.19.0", "https://github.com/pypa/pip/archive/1.3.1.zip"])
 def test_not_supported_editable_requirement(line):
-    with pytest.raises(
-        RequirementError, match="Editable requirement is only supported"
-    ):
+    with pytest.raises(RequirementError, match="Editable requirement is only supported"):
         parse_requirement(line, True)
