@@ -2,10 +2,10 @@ import logging
 import os
 
 import pytest
+from unearth import Link
 
 from pdm.installers import InstallManager
 from pdm.models.candidates import Candidate
-from pdm.models.pip_shims import Link
 from pdm.models.requirements import parse_requirement
 from pdm.utils import fs_supports_symlink
 from tests import FIXTURES
@@ -30,7 +30,10 @@ def test_install_with_file_existing(project):
         req,
         link=Link("http://fixtures.test/artifacts/demo-0.0.1-py2.py3-none-any.whl"),
     )
-    (project.environment.packages_path / "lib/demo.py").touch()
+    lib_path = project.environment.get_paths()["purelib"]
+    os.makedirs(lib_path, exist_ok=True)
+    with open(os.path.join(lib_path, "demo.py"), "w") as fp:
+        fp.write("print('hello')\n")
     installer = InstallManager(project.environment)
     installer.install(candidate)
 
@@ -46,9 +49,7 @@ def test_uninstall_commit_rollback(project):
     installer.install(candidate)
     lib_file = os.path.join(lib_path, "demo.py")
     assert os.path.exists(lib_file)
-    remove_paths = installer.get_paths_to_remove(
-        project.environment.get_working_set()["demo"]
-    )
+    remove_paths = installer.get_paths_to_remove(project.environment.get_working_set()["demo"])
     remove_paths.remove()
     assert not os.path.exists(lib_file)
     remove_paths.rollback()
@@ -67,9 +68,7 @@ def test_rollback_after_commit(project, caplog):
     installer.install(candidate)
     lib_file = os.path.join(lib_path, "demo.py")
     assert os.path.exists(lib_file)
-    remove_paths = installer.get_paths_to_remove(
-        project.environment.get_working_set()["demo"]
-    )
+    remove_paths = installer.get_paths_to_remove(project.environment.get_working_set()["demo"])
     remove_paths.remove()
     remove_paths.commit()
     assert not os.path.exists(lib_file)
@@ -77,10 +76,7 @@ def test_rollback_after_commit(project, caplog):
     remove_paths.rollback()
     assert not os.path.exists(lib_file)
 
-    assert any(
-        record.message == "Can't rollback, not uninstalled yet"
-        for record in caplog.records
-    )
+    assert any(record.message == "Can't rollback, not uninstalled yet" for record in caplog.records)
 
 
 @pytest.mark.parametrize("use_install_cache", [False, True])
@@ -106,9 +102,7 @@ def test_install_wheel_with_cache(project, invoke):
     req = parse_requirement("future-fstrings")
     candidate = Candidate(
         req,
-        link=Link(
-            "http://fixtures.test/artifacts/future_fstrings-1.2.0-py2.py3-none-any.whl"
-        ),
+        link=Link("http://fixtures.test/artifacts/future_fstrings-1.2.0-py2.py3-none-any.whl"),
     )
     installer = InstallManager(project.environment, use_install_cache=True)
     installer.install(candidate)
@@ -118,11 +112,12 @@ def test_install_wheel_with_cache(project, invoke):
         assert os.path.islink(os.path.join(lib_path, "future_fstrings.py"))
         assert os.path.islink(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
     else:
-        assert os.path.isfile(os.path.join(lib_path, "future_fstrings.pth"))
+        assert os.path.isfile(os.path.join(lib_path, "aaa_future_fstrings.pth"))
         assert os.path.isfile(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
 
     cache_path = project.cache("packages") / "future_fstrings-1.2.0-py2.py3-none-any"
     assert cache_path.is_dir()
+    invoke(["run", "python", "-m", "site"], object=project)
     r = invoke(["run", "python", "-c", "import future_fstrings"], obj=project)
     assert r.exit_code == 0
 
@@ -132,7 +127,7 @@ def test_install_wheel_with_cache(project, invoke):
         assert not os.path.exists(os.path.join(lib_path, "future_fstrings.py"))
         assert not os.path.exists(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
     else:
-        assert not os.path.isfile(os.path.join(lib_path, "future_fstrings.pth"))
+        assert not os.path.isfile(os.path.join(lib_path, "aaa_future_fstrings.pth"))
         assert not os.path.isfile(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
     assert not dist.read_text("direct_url.json")
     assert not cache_path.exists()
@@ -140,8 +135,7 @@ def test_install_wheel_with_cache(project, invoke):
 
 def test_url_requirement_is_not_cached(project):
     req = parse_requirement(
-        "future-fstrings @ http://fixtures.test/artifacts/"
-        "future_fstrings-1.2.0-py2.py3-none-any.whl"
+        "future-fstrings @ http://fixtures.test/artifacts/future_fstrings-1.2.0-py2.py3-none-any.whl"
     )
     candidate = Candidate(req)
     installer = InstallManager(project.environment, use_install_cache=True)
@@ -160,9 +154,7 @@ def test_install_wheel_with_data_scripts(project, use_install_cache):
     req = parse_requirement("jmespath")
     candidate = Candidate(
         req,
-        link=Link(
-            "http://fixtures.test/artifacts/jmespath-0.10.0-py2.py3-none-any.whl"
-        ),
+        link=Link("http://fixtures.test/artifacts/jmespath-0.10.0-py2.py3-none-any.whl"),
     )
     installer = InstallManager(project.environment, use_install_cache=use_install_cache)
     installer.install(candidate)
@@ -190,6 +182,4 @@ def test_compress_file_list_for_rename():
         "test-removal/non_exist.py",
     }
     abs_paths = {os.path.join(project_root, path) for path in paths}
-    assert sorted(compress_for_rename(abs_paths)) == [
-        os.path.join(project_root, "test-removal" + os.sep)
-    ]
+    assert sorted(compress_for_rename(abs_paths)) == [os.path.join(project_root, "test-removal" + os.sep)]
