@@ -7,12 +7,13 @@ import pytest
 from packaging.version import parse
 
 from pdm.cli.commands.venv.utils import get_venv_python
+from pdm.environments import PythonEnvironment
 from pdm.exceptions import PdmException
 from pdm.utils import cd
 
 
 def test_project_python_with_pyenv_support(project, mocker, monkeypatch):
-    del project.project_config["python.path"]
+    project._saved_python = None
     project._python = None
     monkeypatch.setenv("PDM_IGNORE_SAVED_PYTHON", "1")
     mocker.patch("pdm.project.core.PYENV_ROOT", str(project.root))
@@ -25,9 +26,7 @@ def test_project_python_with_pyenv_support(project, mocker, monkeypatch):
         "findpython.python.PythonVersion._get_version",
         return_value=parse("3.8.0"),
     )
-    mocker.patch(
-        "findpython.python.PythonVersion._get_interpreter", return_value=sys.executable
-    )
+    mocker.patch("findpython.python.PythonVersion._get_interpreter", return_value=sys.executable)
     assert Path(project.python.path) == pyenv_python
     assert project.python.executable == Path(sys.executable)
 
@@ -52,29 +51,22 @@ def test_project_config_set_invalid_key(project):
         config["foo"] = "bar"
 
 
-def test_project_sources_overriding(project):
+def test_project_sources_overriding_pypi(project):
     project.project_config["pypi.url"] = "https://test.pypi.org/simple"
-    assert project.sources[0]["url"] == "https://test.pypi.org/simple"
+    assert project.sources[0].url == "https://test.pypi.org/simple"
 
-    project.pyproject.settings["source"] = [
-        {"url": "https://example.org/simple", "name": "pypi", "verify_ssl": True}
-    ]
-    assert project.sources[0]["url"] == "https://example.org/simple"
+    project.pyproject.settings["source"] = [{"url": "https://example.org/simple", "name": "pypi", "verify_ssl": True}]
+    assert project.sources[0].url == "https://example.org/simple"
 
 
 def test_project_sources_env_var_expansion(project, monkeypatch):
     monkeypatch.setenv("PYPI_USER", "user")
     monkeypatch.setenv("PYPI_PASS", "password")
-    project.project_config[
-        "pypi.url"
-    ] = "https://${PYPI_USER}:${PYPI_PASS}@test.pypi.org/simple"
+    project.project_config["pypi.url"] = "https://${PYPI_USER}:${PYPI_PASS}@test.pypi.org/simple"
     # expanded in sources
-    assert project.sources[0]["url"] == "https://user:password@test.pypi.org/simple"
+    assert project.sources[0].url == "https://user:password@test.pypi.org/simple"
     # not expanded in project config
-    assert (
-        project.project_config["pypi.url"]
-        == "https://${PYPI_USER}:${PYPI_PASS}@test.pypi.org/simple"
-    )
+    assert project.project_config["pypi.url"] == "https://${PYPI_USER}:${PYPI_PASS}@test.pypi.org/simple"
 
     project.pyproject.settings["source"] = [
         {
@@ -84,12 +76,9 @@ def test_project_sources_env_var_expansion(project, monkeypatch):
         }
     ]
     # expanded in sources
-    assert project.sources[0]["url"] == "https://user:password@example.org/simple"
+    assert project.sources[0].url == "https://user:password@example.org/simple"
     # not expanded in tool settings
-    assert (
-        project.pyproject.settings["source"][0]["url"]
-        == "https://${PYPI_USER}:${PYPI_PASS}@example.org/simple"
-    )
+    assert project.pyproject.settings["source"][0]["url"] == "https://${PYPI_USER}:${PYPI_PASS}@example.org/simple"
 
     project.pyproject.settings["source"] = [
         {
@@ -99,31 +88,27 @@ def test_project_sources_env_var_expansion(project, monkeypatch):
         }
     ]
     # expanded in sources
-    assert project.sources[1]["url"] == "https://user:password@example2.org/simple"
+    assert project.sources[1].url == "https://user:password@example2.org/simple"
     # not expanded in tool settings
-    assert (
-        project.pyproject.settings["source"][0]["url"]
-        == "https://${PYPI_USER}:${PYPI_PASS}@example2.org/simple"
-    )
+    assert project.pyproject.settings["source"][0]["url"] == "https://${PYPI_USER}:${PYPI_PASS}@example2.org/simple"
 
 
 def test_global_project(tmp_path, core):
     project = core.create_project(tmp_path, True)
-    assert project.environment.is_global
+    assert project.is_global
+    assert isinstance(project.environment, PythonEnvironment)
 
 
 def test_auto_global_project(tmp_path, core):
     tmp_path.joinpath(".pdm-home").mkdir()
-    (tmp_path / ".pdm-home/config.toml").write_text(
-        "[global_project]\nfallback = true\n"
-    )
+    (tmp_path / ".pdm-home/config.toml").write_text("[global_project]\nfallback = true\n")
     with cd(tmp_path):
         project = core.create_project(global_config=tmp_path / ".pdm-home/config.toml")
     assert project.is_global
 
 
 def test_project_use_venv(project):
-    del project.project_config["python.path"]
+    project._saved_python = None
     project._python = None
     scripts = "Scripts" if os.name == "nt" else "bin"
     suffix = ".exe" if os.name == "nt" else ""
@@ -131,11 +116,8 @@ def test_project_use_venv(project):
 
     project.project_config["python.use_venv"] = True
     env = project.environment
-    assert (
-        env.interpreter.executable
-        == project.root / "venv" / scripts / f"python{suffix}"
-    )
-    assert env.is_global
+    assert env.interpreter.executable == project.root / "venv" / scripts / f"python{suffix}"
+    assert not env.is_local
 
 
 def test_project_packages_path(project):
@@ -155,11 +137,9 @@ def test_project_auto_detect_venv(project):
 
     project.project_config["python.use_venv"] = True
     project._python = None
-    project.project_config["python.path"] = (
-        project.root / "test_venv" / scripts / f"python{suffix}"
-    ).as_posix()
+    project._saved_python = (project.root / "test_venv" / scripts / f"python{suffix}").as_posix()
 
-    assert project.environment.is_global
+    assert not project.environment.is_local
 
 
 @pytest.mark.path
@@ -170,10 +150,8 @@ def test_ignore_saved_python(project, monkeypatch):
     suffix = ".exe" if os.name == "nt" else ""
     venv.create(project.root / "venv")
     monkeypatch.setenv("PDM_IGNORE_SAVED_PYTHON", "1")
-    assert project.python.executable != project.project_config["python.path"]
-    assert (
-        project.python.executable == project.root / "venv" / scripts / f"python{suffix}"
-    )
+    assert project.python.executable != project._saved_python
+    assert project.python.executable == project.root / "venv" / scripts / f"python{suffix}"
 
 
 def test_select_dependencies(project):
@@ -202,20 +180,9 @@ def test_select_dependencies(project):
     ]
 
 
-def test_global_python_path_config(project_no_init, tmp_path):
-    tmp_path.joinpath(".pdm.toml").unlink()
-    project_no_init.global_config["python.path"] = sys.executable
-    # Recreate the project to clean cached properties
-    p = project_no_init.core.create_project(
-        project_no_init.root, global_config=tmp_path / ".pdm-home/config.toml"
-    )
-    assert p.python.executable == Path(sys.executable)
-    assert "python.path" not in p.project_config
-
-
 @pytest.mark.path
 def test_set_non_exist_python_path(project_no_init):
-    project_no_init.project_config["python.path"] = "non-exist-python"
+    project_no_init._saved_python = "non-exist-python"
     project_no_init._python = None
     assert project_no_init.python.executable.name != "non-exist-python"
 
@@ -223,21 +190,21 @@ def test_set_non_exist_python_path(project_no_init):
 @pytest.mark.usefixtures("venv_backends")
 def test_create_venv_first_time(invoke, project, local_finder):
     project.project_config.update({"venv.in_project": False})
-    del project.project_config["python.path"]
+    project._saved_python = None
     result = invoke(["install"], obj=project)
     assert result.exit_code == 0
     venv_parent = project.root / "venvs"
     venv_path = next(venv_parent.iterdir(), None)
     assert venv_path is not None
 
-    assert Path(project.project_config["python.path"]).relative_to(venv_path)
+    assert Path(project._saved_python).relative_to(venv_path)
 
 
 @pytest.mark.usefixtures("venv_backends", "local_finder")
 @pytest.mark.parametrize("with_pip", [True, False])
 def test_create_venv_in_project(invoke, project, with_pip):
     project.project_config.update({"venv.in_project": True, "venv.with_pip": with_pip})
-    del project.project_config["python.path"]
+    project._saved_python = None
     result = invoke(["install"], obj=project)
     assert result.exit_code == 0
     assert project.root.joinpath(".venv").exists()
@@ -248,7 +215,7 @@ def test_create_venv_in_project(invoke, project, with_pip):
 @pytest.mark.usefixtures("venv_backends")
 def test_find_interpreters_from_venv(invoke, project, local_finder):
     project.project_config.update({"venv.in_project": False})
-    del project.project_config["python.path"]
+    project._saved_python = None
     result = invoke(["install"], obj=project)
     assert result.exit_code == 0
     venv_parent = project.root / "venvs"
@@ -260,7 +227,7 @@ def test_find_interpreters_from_venv(invoke, project, local_finder):
 
 @pytest.mark.usefixtures("local_finder")
 def test_find_interpreters_without_duplicate_relative_paths(invoke, project):
-    del project.project_config["python.path"]
+    project._saved_python = None
     venv.create(project.root / ".venv", clear=True)
     with cd(project.root):
         bin_dir = "Scripts" if os.name == "nt" else "bin"
@@ -293,12 +260,12 @@ def test_load_extra_sources(project):
     project.global_config["pypi.extra.url"] = "https://extra.pypi.org/simple"
     sources = project.sources
     assert len(sources) == 3
-    assert [item["name"] for item in sources] == ["pypi", "custom", "pypi.extra"]
+    assert [item.name for item in sources] == ["pypi", "custom", "extra"]
 
     project.global_config["pypi.ignore_stored_index"] = True
     sources = project.sources
     assert len(sources) == 1
-    assert [item["name"] for item in sources] == ["custom"]
+    assert [item.name for item in sources] == ["custom"]
 
 
 def test_no_index_raise_error(project):
@@ -322,3 +289,23 @@ def test_access_index_with_auth(project):
         session = finder.session
         resp = session.get(url)
         assert resp.ok
+
+
+def test_configured_source_overwriting(project):
+    project.pyproject.settings["source"] = [
+        {
+            "name": "custom",
+            "url": "https://custom.pypi.org/simple",
+        }
+    ]
+    project.global_config["pypi.custom.url"] = "https://extra.pypi.org/simple"
+    project.global_config["pypi.custom.verify_ssl"] = False
+    project.project_config["pypi.custom.username"] = "foo"
+    project.project_config["pypi.custom.password"] = "bar"
+    sources = project.sources
+    assert [source.name for source in sources] == ["pypi", "custom"]
+    custom_source = sources[1]
+    assert custom_source.url == "https://custom.pypi.org/simple"
+    assert custom_source.verify_ssl is False
+    assert custom_source.username == "foo"
+    assert custom_source.password == "bar"
